@@ -1,5 +1,3 @@
-context("aliases")
-
 test_that("aliases work", {
   expect_equal(
     gss_calc %>%
@@ -8,17 +6,18 @@ test_that("aliases work", {
     expected = 1,
     tolerance = eps
   )
-  
+
   expect_silent(gss_permute %>% get_ci())
 })
 
 test_that("old aliases produce warning", {
-  expect_warning(
-    gss_calc %>%
+  expect_snapshot(
+    res <- gss_calc %>%
       p_value(obs_stat = -0.2, direction = "right") %>%
-      dplyr::pull(),
-    expected = 1
+      dplyr::pull()
   )
-  
-  expect_warning(gss_permute %>% conf_int())
+
+  expect_equal(res, 1)
+
+  expect_snapshot(res_ <- gss_permute %>% conf_int())
 })
